==> vlc_0.3.0.orig.tar.gz: vlc-0.3.0/plugins/mad/mad_adec.h <==
/***************************************************************************
             mad_adec.h  -  description
                -------------------
    begin                : Mon Nov 5 2001
    copyright            : (C) 2001 by Jean-Paul Saman
    email                : jpsaman@wxs.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _VLC_MAD_ADEC_H_
#define _VLC_MAD_ADEC_H_
/*****************************************************************************
 * mad_adec_thread_t : mad decoder thread descriptor
 *****************************************************************************/

// FIXME: Ugly define inside a decoder
#define ADEC_FRAME_SIZE (2*1152)
// MAD_BUFFER_MDLEN (511 + 2048 + MAD_BUFLEN_GUARD) and MAD_BUFLEN_GUARD is 8
#define MAD_BUFFER_SIZE (MAD_BUFFER_MDLEN)
//#define MAD_BUFFER_SIZE (ADEC_FRAME_SIZE*2)
#define MAD_OUTPUT_SIZE (ADEC_FRAME_SIZE*2)

typedef struct mad_adec_thread_s
{
    /*
     * Decoder properties
     */
    struct mad_decoder *libmad_decoder;
    mad_timer_t         libmad_timer;  
    byte_t              buffer[MAD_BUFFER_SIZE]; 
   
    /*
     * Thread properties
     */
    vlc_thread_t        thread_id;                /* id for thread functions */

    /*
     * Input properties
     */
    decoder_fifo_t *    p_fifo;                /* stores the PES stream data */
    data_packet_t *     p_data;
    decoder_config_t *  p_config;

    /* Store i_pts for syncing audio frames */
    mtime_t             i_current_pts, i_next_pts;

    /*
     * Output properties
     */
    aout_fifo_t *       p_aout_fifo; /* stores the decompressed audio frames */

} mad_adec_thread_t;

/*****************************************************************************
 * Prototypes
 *****************************************************************************/
vlc_thread_t            mad_adec_CreateThread( decoder_config_t * p_config );

#endif

==> vlc-0.4.4.tar.gz: vlc-0.4.4/plugins/mad/mad_adec.h <==
/***************************************************************************
             mad_adec.h  -  description
                -------------------
    begin                : Mon Nov 5 2001
    copyright            : (C) 2001 by Jean-Paul Saman
    email                : jpsaman@wxs.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _VLC_MAD_ADEC_H_
#define _VLC_MAD_ADEC_H_

/*****************************************************************************
 * mad_adec_thread_t : mad decoder thread descriptor
 *****************************************************************************/

enum mad_scaling { FAST_SCALING, MPG321_SCALING };

typedef struct mad_adec_thread_s
{
    /*
     * Decoder properties
     */
    struct mad_decoder *libmad_decoder;
    mad_timer_t         libmad_timer;  
    byte_t              buffer[MAD_BUFFER_MDLEN];
   
    /*
     * Thread properties
     */
    vlc_thread_t        thread_id;                /* id for thread functions */

    /*
     * Input properties
     */
    decoder_fifo_t *    p_fifo;                /* stores the PES stream data */
    data_packet_t *     p_data;
    decoder_config_t *  p_config;

    /* Store i_pts for syncing audio frames */
    mtime_t             i_current_pts, i_next_pts;

    /*
     * Output properties
     */
    aout_fifo_t *       p_aout_fifo; /* stores the decompressed audio frames */
    enum mad_scaling	  audio_scaling;

} mad_adec_thread_t;

/*****************************************************************************
 * Prototypes
 *****************************************************************************/
vlc_thread_t            mad_adec_CreateThread( decoder_config_t * p_config );

#endif
